﻿import es
import gamethread
import keymenulib
import langlib
import playerlib
import popuplib

common = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/common.ini")
messages = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/admin/messages.ini")

# ******************** Load ********************
def load():
	es.keygroupload("soccer_mod_admins", "soccer_mod")
	es.keygroupload("soccer_mod_maps", "soccer_mod")
	es.keygroupcreate("sm_keygroup_set")

	create_popup()

	es.load("soccer_mod_2010/manager")

# ******************** Create popup ********************
def create_popup():
	text = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/admin/popup_admin.ini")

	popup = popuplib.create("sm_popup_admin")

	line = "SOCCER MOD %s" % (text("title"))
	popup.addline(line)

	popup.addline(" ")

	number = 0

	enabled = es.ServerVar("sm_module_match_on")
	if enabled == 1:
		number += 1
		line = "->%s. %s" % (number, text("match"))
		popup.addline(line)
		popup.select(number, match)

	enabled = es.ServerVar("sm_module_cap_on")
	if enabled == 1:
		number += 1
		line = "->%s. %s" % (number, text("cap"))
		popup.addline(line)
		popup.select(number, cap)

	enabled = es.ServerVar("sm_module_referee_on")
	if enabled == 1:
		number += 1
		line = "->%s. %s" % (number, text("referee"))
		popup.addline(line)
		popup.select(number, referee)

	enabled = es.ServerVar("sm_module_training_on")
	if enabled == 1:
		number += 1
		line = "->%s. %s" % (number, text("training"))
		popup.addline(line)
		popup.select(number, training)

	number += 1
	line = "->%s. %s" % (number, text("map"))
	popup.addline(line)
	popup.select(number, change_map_select)

	number += 1
	line = "->%s. %s" % (number, text("settings"))
	popup.addline(line)
	popup.select(number, settings)

	number += 1
	line = "->%s. %s" % (number, text("manager"))
	popup.addline(line)
	popup.select(number, manager)

	popup.addline(" ")
	line = "0. %s" % (common("close"))
	popup.addline(line)

	number += 1
	while number < 10:
		popup.submenu(number, "sm_popup_admin")
		number += 1

# ******************** Events ********************
def es_map_start(event_var):
	exists = es.exists("key", "soccer_mod_maps", event_var["mapname"])
	if exists == 1:
		es.set("soccer_mod_allowed", 1)
		es.server.queuecmd("phys_pushscale 900")
	else:
		es.set("soccer_mod_allowed", 0)
		es.server.queuecmd("phys_pushscale 1")

	es.keygroupdelete("sm_keygroup_set")
	es.keygroupcreate("sm_keygroup_set")

def player_disconnect(event_var):
	name = "sm_popup_%s" % (event_var["userid"])
	if popuplib.exists(name):
		popuplib.delete(name)

	name = "sm_keymenu_%s" % (event_var["userid"])
	if keymenulib.exists(name):
		keymenulib.delete(name)

# ******************** Commands ********************
def cmd_admin():
	userid = es.getcmduserid()
	steamid = es.getplayersteamid(userid)

	exists = es.exists("key", "soccer_mod_admins", steamid)
	if exists == 1:
		popuplib.send("sm_popup_admin", userid)
	else:
		player = playerlib.getPlayer(userid)
		tokens = {}
		es.tell(userid, "#green", messages("admin", tokens, player.get("lang")))

# ******************** Popup choices ********************
def match(userid, choice, popupid):
	admin_popup_check("match", userid)

def cap(userid, choice, popupid):
	admin_popup_check("cap", userid)

def referee(userid, choice, popupid):
	admin_popup_check("referee", userid)

def training(userid, choice, popupid):
	admin_popup_check("training", userid)

def change_map_select(userid, choice, popupid):
	name = "sm_keymenu_%s" % (userid)
	if keymenulib.exists(name):
		keymenulib.delete(name)

	tokens = {}
	player = playerlib.getPlayer(userid)

	keymenu = keymenulib.create(name, "target", change_map_choice, "soccer_mod_maps", "#key", "#key", messages("change_map", tokens, player.get("lang")))
	keymenu.backmenu("sm_popup_admin")
	keymenulib.send(name, userid)

def settings(userid, choice, popupid):
	admin_popup_check("settings", userid)

def manager(userid, choice, popupid):
	steamid = es.getplayersteamid(userid)

	check = int(es.keygetvalue("soccer_mod_admins", steamid, "manager"))
	if check == 1:
		popuplib.send("sm_popup_admin_manager", userid)
	else:
		tokens = {}
		player = playerlib.getPlayer(userid)
		es.tell(userid, "#green", messages("manager", tokens, player.get("lang")))
		popuplib.send("sm_popup_admin", userid)

# ******************** Keymenu choices ********************
def change_map_choice(userid, choice, keymenuname):
	tokens = {}
	player = playerlib.getPlayer(userid)

	check = es.ServerVar("match")
	if check == 0:
		exists = es.exists("map", choice)
		if exists == 1:
			name = es.getplayername(userid)
			tokens['name'] = name
			tokens['map'] = choice
			lang_msg("changed_map", tokens)

			cmd = "changelevel %s" % (choice)
			gamethread.delayed(3, es.server.queuecmd, (cmd))
		else:
			tokens['name'] = choice
			es.tell(userid, "#green", messages("map_no_exist", tokens, player.get("lang")))

			popuplib.send("sm_popup_admin", userid)
	else:
		es.tell(userid, "#green", "You can not change the map during a match.")
		popuplib.send("sm_popup_admin", userid)

# ******************** Functions ********************
def lang_msg(text, tokens):
	myPlayerList = playerlib.getPlayerList("#human")
	for player in myPlayerList:
		es.tell(player.userid, "#green", messages(text, tokens, player.get("lang")))

def admin_popup_check(module, userid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	check = es.ServerVar("soccer_mod_allowed")
	if check == 1:
		steamid = es.getplayersteamid(userid)
		check = int(es.keygetvalue("soccer_mod_admins", steamid, module))
		if check == 1:
			popup = "sm_popup_admin_%s" % (module)
			popuplib.send(popup, userid)
		else:
			es.tell(userid, "#green", messages(module, tokens, player.get("lang")))
			popuplib.send("sm_popup_admin", userid)
	else:
		es.tell(userid, "#green", common("not_allowed", tokens, player.get("lang")))
		popuplib.send("sm_popup_admin", userid)

# ******************** Unload ********************
def unload():
	es.keygroupdelete("soccer_mod_admins")
	es.keygroupdelete("soccer_mod_maps")
	es.keygroupdelete("sm_keygroup_set")

	popuplib.delete("sm_popup_admin")

	es.unload("soccer_mod_2010/manager")