﻿import es
import gamethread
import langlib
import playerlib
import popuplib

common = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/common.ini")
messages = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/training/messages_training.ini")

# ******************** Load ********************
def load():
	create_popup()

	es.keygroupcreate("soccer_mod_training")

	es.set("sm_training_goals_disabled", 0)

	es.load("soccer_mod_2010/training/cannon")

# ******************** Create popup ********************
def create_popup():
	text = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/training/popup_admin_training.ini")

	popup = popuplib.create("sm_popup_admin_training")

	line = "SOCCER MOD %s" % (text("title"))
	popup.addline(line)

	popup.addline(" ")

	line = "->1. %s" % (text("cannon"))
	popup.addline(line)

	line = "->2. %s" % (text("spawn"))
	popup.addline(line)

	line = "->3. %s" % (text("disable_goals"))
	popup.addline(line)

	line = "->4. %s" % (text("enable_goals"))
	popup.addline(line)

	popup.addline(" ")

	line = "->9. %s" % (common("back"))
	popup.addline(line)

	popup.addline(" ")

	line = "->0. %s" % (common("close"))
	popup.addline(line)

	popup.submenu(1, "sm_popup_admin_training_cannon")
	popup.select(2, spawn_ball)
	popup.select(3, disable_goals)
	popup.select(4, enable_goals)
	popup.submenu(5, "sm_popup_admin_training")
	popup.submenu(6, "sm_popup_admin_training")
	popup.submenu(7, "sm_popup_admin_training")
	popup.submenu(8, "sm_popup_admin_training")
	popup.submenu(9, "sm_popup_admin")

# ******************** Events ********************
def es_map_start(event_var):
	es.set("sm_training_goals_disabled", 0)

def round_start(event_var):
	enabled = es.ServerVar("soccer_mod_allowed")
	if enabled == 1:
		delete_keygroup()
		es.keygroupcreate("soccer_mod_training")

		check = es.ServerVar("sm_training_goals_disabled")
		if check == 1:
			remove_trigger()
			gamethread.delayed(0.1, remove_trigger)

def player_disconnect(event_var):
	enabled = es.ServerVar("soccer_mod_allowed")
	if enabled == 1:
		players = es.getUseridList()
		number = 0
		for player in players:
			number += 1
		if number < 1:
			es.set("sm_training_goals_disabled", 0)

# ******************** Popup choices ********************
def spawn_ball(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	exists = es.exists("key", "soccer_mod_training", player.steamid)
	if exists == 0:
		check = es.ServerVar("match")
		if check == 0:
			model = es.ServerVar("sm_training_model_ball")
			cmd = "es_xprop_physics_create %s %s" % (userid, model)
			es.server.queuecmd(cmd)

			gamethread.delayed(0.01, create_key, (player.steamid))

			es.tell(userid, "#green", messages("spawn", tokens, player.get("lang")))
		else:
			es.tell(userid, "#green", messages("no_ball_match", tokens, player.get("lang")))
	else:
		ball_index = es.keygetvalue("soccer_mod_training", player.steamid, "ball_index")
		if ball_index > 0:
			es.remove(ball_index)

		es.keydelete("soccer_mod_training", player.steamid)

		es.tell(userid, "#green", messages("remove", tokens, player.get("lang")))

	popuplib.send("sm_popup_admin_training", userid)

def disable_goals(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	check = es.ServerVar("match")
	if check == 0:
		check = es.ServerVar("sm_training_goals_disabled")
		if check == 0:
			remove_trigger()
			gamethread.delayed(0.1, remove_trigger)

			es.set("sm_training_goals_disabled", 1)

			name = es.getplayername(userid)
			tokens["name"] = name
			lang_msg("disabled", tokens)
		else:
			es.tell(userid, "#green", messages("already_disabled", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages("no_disable_match", tokens, player.get("lang")))

	popuplib.send("sm_popup_admin_training", userid)

def enable_goals(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	check = es.ServerVar("sm_training_goals_disabled")
	if check == 1:
		cmd = "mp_restartgame 1"
		es.server.queuecmd(cmd)
		es.set("sm_training_goals_disabled", 0)

		name = es.getplayername(userid)
		tokens["name"] = name
		lang_msg("enabled", tokens)
	else:
		es.tell(userid, "#green", messages("already_enabled", tokens, player.get("lang")))

	popuplib.send("sm_popup_admin_training", userid)

# ******************** Functions ********************
def lang_msg(text, tokens):
	myPlayerList = playerlib.getPlayerList("#human")
	for player in myPlayerList:
		es.tell(player.userid, "#green", messages(text, tokens, player.get("lang")))

def create_key(steamid):
	es.keycreate("soccer_mod_training", steamid)
	entityid = es.ServerVar("eventscripts_lastgive")
	es.keysetvalue("soccer_mod_training", steamid, "ball_index", entityid)

def remove_trigger():
	entity_index = es.getentityindex("trigger_hurt")
	if entity_index > 0:
		es.remove(entity_index)

def delete_keygroup():
	exists = es.exists("keygroup", "soccer_mod_training")
	if exists == 1:
		es.keygroupdelete("soccer_mod_training")

def delete_popup():
	if popuplib.exists("sm_popup_admin_training"):
		popuplib.delete("sm_popup_admin_training")

# ******************** Unload ********************
def unload():
	delete_keygroup()
	delete_popup()

	es.unload("soccer_mod_2010/training/cannon")